#!/bin/bash

s=slt
t=bdl

mode=melspc_r3

out_dir=exp/cfs2_vc/${mode}/${s}_to_${t}
mkdir -p ${out_dir}

n_gpu=1
export CUDA_VISIBLE_DEVICES=0

../../../tools/venv/bin/python3 \
    ../../../espnet2/bin/vc_train.py \
    --use_preprocessor false \
    --normalize global_mvn \
    --s_normalize global_mvn \
    --pitch_normalize global_mvn \
    --energy_normalize global_mvn \
    --pitch_s_normalize global_mvn \
    --energy_s_normalize global_mvn \
    --pitch_s_extract dio \
    --energy_s_extract energy \
    --resume true \
    --output_dir ${out_dir} \
    --config conf/tuning/train_cfs2_vc_${mode}.yaml \
    --feats_s_extract fbank \
    --feats_s_extract_conf n_fft=1024 \
    --feats_s_extract_conf hop_length=256 \
    --feats_s_extract_conf win_length=null \
    --feats_s_extract_conf fs=24000 \
    --feats_s_extract_conf fmin=80 \
    --feats_s_extract_conf fmax=7600 \
    --feats_s_extract_conf n_mels=80 \
    --feats_extract fbank \
    --feats_extract_conf n_fft=1024 \
    --feats_extract_conf hop_length=256 \
    --feats_extract_conf win_length=null \
    --feats_extract_conf fs=24000 \
    --feats_extract_conf fmin=80 \
    --feats_extract_conf fmax=7600 \
    --feats_extract_conf n_mels=80 \
    --train_data_path_and_name_and_type dump/raw/${s}_train_no_dev/wav.scp,speech_s,sound \
    --train_data_path_and_name_and_type dump/raw/${t}_train_no_dev/wav.scp,speech,sound \
    --train_shape_file stats/jets/${s}/tts_stats_raw_phn_tacotron_g2p_en_no_space/train/speech_s_shape \
    --train_shape_file stats/jets/${t}/tts_stats_raw_phn_tacotron_g2p_en_no_space/train//speech_shape \
    --valid_data_path_and_name_and_type dump/raw/${s}_dev/wav.scp,speech_s,sound \
    --valid_data_path_and_name_and_type dump/raw/${t}_dev/wav.scp,speech,sound \
    --valid_shape_file stats/jets/${s}/tts_stats_raw_phn_tacotron_g2p_en_no_space/valid/speech_s_shape \
    --valid_shape_file stats/jets/${t}/tts_stats_raw_phn_tacotron_g2p_en_no_space/valid/speech_shape \
    --train_data_path_and_name_and_type exp/vtn/melspc_r3/${s}_to_${t}/inference_use_teacher_forcing_200epoch/train_no_dev/durations/durations,durations,text_int \
    --valid_data_path_and_name_and_type exp/vtn/melspc_r3/${s}_to_${t}/inference_use_teacher_forcing_200epoch/dev/durations/durations,durations,text_int \
    --train_data_path_and_name_and_type stats/jets/${t}/tts_stats_raw_phn_tacotron_g2p_en_no_space/train/collect_feats/pitch.scp,pitch,npy \
    --valid_data_path_and_name_and_type stats/jets/${t}/tts_stats_raw_phn_tacotron_g2p_en_no_space/valid/collect_feats/pitch.scp,pitch,npy \
    --train_data_path_and_name_and_type stats/jets/${t}/tts_stats_raw_phn_tacotron_g2p_en_no_space/train/collect_feats/energy.scp,energy,npy \
    --valid_data_path_and_name_and_type stats/jets/${t}/tts_stats_raw_phn_tacotron_g2p_en_no_space/valid/collect_feats/energy.scp,energy,npy \
    --train_data_path_and_name_and_type stats/jets/${s}/tts_stats_raw_phn_tacotron_g2p_en_no_space/train/collect_feats/pitch.scp,pitch_s,npy \
    --valid_data_path_and_name_and_type stats/jets/${s}/tts_stats_raw_phn_tacotron_g2p_en_no_space/valid/collect_feats/pitch.scp,pitch_s,npy \
    --train_data_path_and_name_and_type stats/jets/${s}/tts_stats_raw_phn_tacotron_g2p_en_no_space/train/collect_feats/energy.scp,energy_s,npy \
    --valid_data_path_and_name_and_type stats/jets/${s}/tts_stats_raw_phn_tacotron_g2p_en_no_space/valid/collect_feats/energy.scp,energy_s,npy \
    --pitch_extract_conf fs=24000 \
    --pitch_extract_conf n_fft=1024 \
    --pitch_extract_conf hop_length=256 \
    --pitch_extract_conf f0max=400 \
    --pitch_extract_conf f0min=80 \
    --pitch_extract_conf reduction_factor=1 \
    --pitch_extract_conf use_token_averaged_f0=false \
    --pitch_s_extract_conf fs=24000 \
    --pitch_s_extract_conf n_fft=1024 \
    --pitch_s_extract_conf hop_length=256 \
    --pitch_s_extract_conf f0max=400 \
    --pitch_s_extract_conf f0min=80 \
    --pitch_s_extract_conf reduction_factor=1 \
    --pitch_s_extract_conf use_token_averaged_f0=false \
    --pitch_normalize_conf stats_file=stats/jets/${t}/tts_stats_raw_phn_tacotron_g2p_en_no_space/train/pitch_stats.npz \
    --pitch_s_normalize_conf stats_file=stats/jets/${s}/tts_stats_raw_phn_tacotron_g2p_en_no_space/train/pitch_stats.npz \
    --energy_extract_conf fs=24000 \
    --energy_extract_conf n_fft=1024 \
    --energy_extract_conf hop_length=256 \
    --energy_extract_conf win_length=null \
    --energy_extract_conf reduction_factor=1 \
    --energy_extract_conf use_token_averaged_energy=false \
    --energy_s_extract_conf fs=24000 \
    --energy_s_extract_conf n_fft=1024 \
    --energy_s_extract_conf hop_length=256 \
    --energy_s_extract_conf win_length=null \
    --energy_s_extract_conf reduction_factor=1 \
    --energy_s_extract_conf use_token_averaged_energy=false \
    --energy_normalize_conf stats_file=stats/jets/${t}/tts_stats_raw_phn_tacotron_g2p_en_no_space/train/energy_stats.npz \
    --energy_s_normalize_conf stats_file=stats/jets/${s}/tts_stats_raw_phn_tacotron_g2p_en_no_space/train/energy_stats.npz \
    --normalize_conf stats_file=stats/jets/${t}/tts_stats_raw_phn_tacotron_g2p_en_no_space/train/feats_stats.npz \
    --s_normalize_conf stats_file=stats/jets/${s}/tts_stats_raw_phn_tacotron_g2p_en_no_space/train/feats_stats.npz \
    --ngpu ${n_gpu} \
    --multiprocessing_distributed True \
    2>&1 | tee ${out_dir}/train.log
